<?php

require __DIR__ . '/vendor/autoload.php';

use Jcupitt\Vips;
use Jcupitt\Vips\Exception as VipsException;

// libvips caching is not needed
Vips\Config::cacheSetMax(0);
Vips\Config::cacheSetMaxFiles(0);
Vips\Config::cacheSetMaxMem(0);

// Target width = 710
$width = 710;

// Target height = 710
$height = 710;

$file = __DIR__ . '/image.jpg';

for ($i = 0; $i < 1024; $i++) {
    $image = Vips\Image::newFromFile($file, ['access' => 'sequential']);

    // 768 pixels
    $inputWidth = $image->width;
    // 1024 pixels
    $inputHeight = $image->height;

    // Scaling calculations
    $targetResizeWidth = $width;
    $targetResizeHeight = $height;

    // Fixed width and height
    $xFactor = (float)($inputWidth / $width);
    $yFactor = (float)($inputHeight / $height);
    if ($xFactor > $yFactor) {
        $targetResizeHeight = (int)round((float)($inputHeight / $xFactor));
        $yFactor = $xFactor;
    } else {
        $targetResizeWidth = (int)round((float)($inputWidth / $yFactor));
        $xFactor = $yFactor;
    }

    // Calculate integral box shrink
    $xShrink = max(1, (int)floor($xFactor));
    $yShrink = max(1, (int)floor($yFactor));

    // Calculate residual float affine transformation
    $xResidual = (float)($xShrink / $xFactor);
    $yResidual = (float)($yShrink / $yFactor);

    $shouldReduce = $xResidual != 1.0 || $yResidual != 1.0;

    // Use affine increase or kernel reduce with the remaining float part
    if ($xResidual != 1.0 || $yResidual != 1.0) {
        // Perform kernel-based reduction
        if ($yResidual < 1.0 || $xResidual < 1.0) {
            // Use *magick centre sampling convention instead of corner sampling
            $centreSampling = true;

            if ($yResidual < 1.0) {
                $image = $image->reducev(1.0 / $yResidual, [
                    'kernel' => Vips\Kernel::LANCZOS3,
                    'centre' => $centreSampling
                ]);
            }
            if ($xResidual < 1.0) {
                $image = $image->reduceh(1.0 / $xResidual, [
                    'kernel' => Vips\Kernel::LANCZOS3,
                    'centre' => $centreSampling
                ]);
            }
        }
    }

    try {
        // Write to buffer
        $buffer = $image->writeToBuffer('.' . 'jpg');
    } catch (VipsException $e) {
        echo $e->getMessage();
    }
}